@@ -30,6 +30,7 @@
 #include <glib-object.h>
 #include <gst/gst.h>
 #include <gst/gconf/gconf.h>
+#include <gst/tag/tag.h>
 #include <profiles/gnome-media-profiles.h>
 #include "sj-extractor.h"
 #include "sj-structures.h"
@@ -415,6 +416,10 @@ void sj_extractor_extract_track (SjExtractor *extractor, const TrackDetails *tra
                             GST_TAG_TRACK_NUMBER, track->number,
                             GST_TAG_TRACK_COUNT, track->album->number,
                             GST_TAG_ALBUM, track->album->title,
+                            GST_TAG_MUSICBRAINZ_ALBUMID, track->album->album_id,
+                            GST_TAG_MUSICBRAINZ_ALBUMARTISTID, track->album->artist_id,
+                            GST_TAG_MUSICBRAINZ_ARTISTID, track->artist_id,
+                            GST_TAG_MUSICBRAINZ_TRACKID, track->track_id,
                             GST_TAG_ENCODER, _("Sound Juicer"),
                             GST_TAG_ENCODER_VERSION, VERSION,
                             NULL);
@@ -425,6 +430,13 @@ void sj_extractor_extract_track (SjExtractor *extractor, const TrackDetails *tra
                               GST_TAG_GENRE, sj_genre_name (track->genre),
                               NULL);
         }
+        if (track->album->release_date) {
+          gst_tag_setter_add (GST_TAG_SETTER (elt->data),
+                              /* TODO: is APPEND right? */
+                              GST_TAG_MERGE_APPEND,
+                              GST_TAG_DATE, g_date_get_julian (track->album->release_date),
+                              NULL);
+        }
         taggable = TRUE;
       }
     }
