@@ -29,11 +29,13 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
+#include <nautilus-burn-drive.h>
 #include <libgnome/gnome-help.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <profiles/gnome-media-profiles.h>
 #include <gst/gst.h>
 
+#include "bacon-message-connection.h"
 #include "sj-about.h"
 #include "sj-genres.h"
 #include "sj-metadata.h"
@@ -66,9 +68,10 @@ static GtkWidget *track_listview, *extract_button;
 static GtkWidget *status_bar;
 static GtkWidget *extract_menuitem, *select_all_menuitem, *deselect_all_menuitem;
 GtkListStore *track_store;
+static BaconMessageConnection *connection;
 
 const char *base_path, *path_pattern, *file_pattern;
-const char *device = NULL;
+NautilusBurnDrive *drive = NULL;
 gboolean strip_chars;
 gboolean eject_finished;
 gboolean extracting = FALSE;
@@ -81,6 +84,7 @@ static AlbumDetails *current_album;
 int autostart = FALSE;
 
 #define DEFAULT_PARANOIA 4
+#define RAISE_WINDOW "raise-window"
 
 static void error_on_start (GError *error)
 {
@@ -120,7 +124,7 @@ void on_destroy_signal (GtkMenuItem *item, gpointer user_data)
  */
 void on_eject_activate (GtkMenuItem *item, gpointer user_data)
 {
-  eject_cdrom (device, GTK_WINDOW (main_window));
+  nautilus_burn_drive_eject (drive);
 }
 
 gboolean poll_tray_opened (gpointer data)
@@ -130,7 +134,7 @@ gboolean poll_tray_opened (gpointer data)
   if (extracting == TRUE)
     return TRUE;
 
-  new_status = tray_is_opened (device);
+  new_status = nautilus_burn_drive_door_is_open (drive);
   if (new_status != tray_opened && new_status == FALSE) {
     reread_cd (TRUE);
   } else if (new_status != tray_opened && new_status == TRUE) {
@@ -468,14 +472,15 @@ metadata_cb (SjMetadata *m, GList *albums, GError *error)
   
   if (error && !(error->code == SJ_ERROR_CD_NO_MEDIA)) {
     GtkWidget *dialog;
+    
     dialog = gtk_message_dialog_new (realized ? GTK_WINDOW (main_window) : NULL, 0,
                                      GTK_MESSAGE_ERROR,
                                      GTK_BUTTONS_CLOSE,
-				     "<b>%s</b>\n\n%s\n%s: %s",
-				      _("Could not read the CD"),
-				      _("Sound Juicer could not read the track listing on this CD."),
-				      _("Reason"),
-				      error->message);
+                                     "<b>%s</b>\n\n%s\n%s: %s",
+                                     _("Could not read the CD"),
+                                     _("Sound Juicer could not read the track listing on this CD."),
+                                     _("Reason"),
+                                     error->message);
     gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
@@ -512,6 +517,15 @@ metadata_cb (SjMetadata *m, GList *albums, GError *error)
   }
 }
 
+static gboolean
+is_audio_cd (NautilusBurnDrive *drive)
+{
+  gboolean audio;
+  if (drive == NULL) return FALSE;
+  nautilus_burn_drive_get_media_type_full (drive, NULL, NULL, NULL, &audio);
+  return audio;
+}
+
 /**
  * Utility function to reread a CD
  */
@@ -534,7 +548,7 @@ static void reread_cd (gboolean ignore_no_media)
   /* Set statusbar message */
   gtk_statusbar_push(GTK_STATUSBAR(status_bar), 0, _("Retrieving track listing...please wait."));
 
-  if (!is_audio_cd (device)) {
+  if (!is_audio_cd (drive)) {
     update_ui_for_album (NULL);
     gtk_statusbar_pop(GTK_STATUSBAR(status_bar), 0);
     if (realized)
@@ -573,6 +587,7 @@ static void reread_cd (gboolean ignore_no_media)
  */
 void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
+  const char *device;
   gboolean ignore_no_media = GPOINTER_TO_INT (user_data);
   g_assert (strcmp (entry->key, GCONF_DEVICE) == 0);
 
@@ -595,6 +610,7 @@ void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, g
       exit (1);
 #endif
     }
+    drive = nautilus_burn_drive_new_from_path (device);
   } else {
     device = gconf_value_get_string (entry->value);
     if (access (device, R_OK) != 0) {
@@ -615,13 +631,15 @@ void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, g
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       /* Set a null device */
-      device = NULL;
+      drive = NULL;
+    } else {
+      drive = nautilus_burn_drive_new_from_path (device);
     }
   }
   sj_metadata_set_cdrom (metadata, device);
   sj_extractor_set_device (extractor, device);
 
-  tray_opened = tray_is_opened (device);
+  tray_opened = nautilus_burn_drive_door_is_open (drive);
   if (tray_opened == FALSE) {
     reread_cd (ignore_no_media);
   }
@@ -921,6 +939,16 @@ static GtkTreeModel* populate_genre_list(void) {
   return GTK_TREE_MODEL (store);
 }
 
+static void
+on_message_received (const char *message, gpointer user_data)
+{
+  if (message == NULL)
+    return;
+  if (strcmp (RAISE_WINDOW, message) == 0) {
+    gtk_window_present (GTK_WINDOW (main_window));
+  }
+}
+
 int main (int argc, char **argv)
 {
   GError *error = NULL;
@@ -943,6 +971,15 @@ int main (int argc, char **argv)
                       NULL);
   g_set_application_name (_("Sound Juicer"));
 
+  connection = bacon_message_connection_new ("sound-juicer");
+  if (bacon_message_connection_get_is_server (connection) == FALSE) {
+	  bacon_message_connection_send (connection, RAISE_WINDOW);
+	  bacon_message_connection_free (connection);
+	  exit (0);
+  } else {
+    bacon_message_connection_set_callback (connection, on_message_received, NULL);
+  }
+
   metadata = SJ_METADATA (sj_metadata_musicbrainz_new ());
   error = sj_metadata_get_new_error (metadata);
   if (error) {
@@ -975,8 +1012,16 @@ int main (int argc, char **argv)
   gnome_media_profiles_init (gconf_client);
 
   glade_init ();
-  glade = glade_xml_new (DATADIR"/sound-juicer/sound-juicer.glade", NULL, NULL);
-  g_assert (glade != NULL);
+  glade = glade_xml_new ("../data/sound-juicer.glade", NULL, NULL);
+  if (glade == NULL) {
+    glade = glade_xml_new (DATADIR"/sound-juicer/sound-juicer.glade", NULL, NULL);
+  }
+  if (glade == NULL) {
+    g_error_new (0, 0, _("The interface file for Sound Juicer could not be read."));
+    error_on_start (error);
+    g_error_free (error);
+    exit (1);
+  }
   glade_xml_signal_autoconnect (glade);
 
   main_window = glade_xml_get_widget (glade, "main_window");
@@ -1082,7 +1127,7 @@ int main (int argc, char **argv)
   }
 
   /* Poke the CD drive every now and then */
-  tray_opened = tray_is_opened (device);
+  tray_opened = nautilus_burn_drive_door_is_open (drive);
   poll_id = g_timeout_add (2000, poll_tray_opened, NULL);
 
   gtk_main ();
