@@ -276,18 +276,24 @@ static void pattern_label_update (void)
   char *file_value, *path_value, *example, *format;
   gboolean strip;
   static AlbumDetails sample_album = {
-    N_("Album Title"),
-    N_("Album Artist"),
-    0,
-    NULL
+    N_("Album Title"), /* title */
+    N_("Album Artist"), /* artist */
+    0, /* number of tracks*/
+    NULL, /* track list */
+    NULL, /* release date */
+    NULL, /* album ID */
+    NULL, /* artist ID */
   };
   static TrackDetails sample_track = {
-    &sample_album,
-    9,
-    N_("Track Title"),
-    N_("Track Artist"),
-    60,
-    LAST_GENRE
+    &sample_album,  /*album */
+    9, /* track number */
+    N_("Track Title"), /* title */
+    N_("Track Artist"), /* artist */
+    60, /* duration */
+    LAST_GENRE, /* genre */
+    NULL, /* track ID */
+    NULL, /* artist ID */
+    {0,0,0,0} /* treeview iterator */
   };
   /* Magic to i18n-ize the sample strings. */
   static gboolean been_here = FALSE;
@@ -330,7 +336,6 @@ static void path_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
   char *value;
   int i = 0;
   g_return_if_fail (strcmp (entry->key, GCONF_PATH_PATTERN) == 0);
-  g_return_if_fail (entry->value->type == GCONF_VALUE_STRING);
 
   if (entry->value == NULL) {
     value = g_strdup (path_patterns[0].pattern);
@@ -352,7 +357,6 @@ static void file_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
   int i = 0;
   
   g_return_if_fail (strcmp (entry->key, GCONF_FILE_PATTERN) == 0);
-  g_return_if_fail (entry->value->type == GCONF_VALUE_STRING);
   
   if (entry->value == NULL) {
     value = g_strdup (file_patterns[0].pattern);
