@@ -25,16 +25,9 @@
 
 #include <sys/types.h>
 #include <glib/gerror.h>
-#include <gtk/gtkwindow.h>
 
 void mkdir_recursive (const char *path, mode_t permission_bits, GError **error);
 
-void eject_cdrom (const char* device, GtkWindow *parent);
-
-gboolean tray_is_opened (const char *device);
-
-gboolean is_audio_cd (const char *device);
-
 void g_list_deep_free (GList *l, GFunc free_func);
 
 #endif /* SJ_UTIL_H */
